# MessagePartHeader

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The name of the header before the &#x60;:&#x60; separator. For example, &#x60;To&#x60;. | [optional] 
**value** | **str** | The value of the header after the &#x60;:&#x60; separator. For example, &#x60;someuser@example.com&#x60;. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

